@@ -49,6 +49,7 @@
 using namespace xmlsignature;
 using namespace xmltooling::logging;
 using namespace xmltooling;
+using boost::scoped_ptr;
 using namespace std;
 
 namespace xmltooling {
@@ -102,13 +103,13 @@ namespace xmltooling {
     };
 
 
-    static XMLCh fullCRLChain[] =		    UNICODE_LITERAL_12(f,u,l,l,C,R,L,C,h,a,i,n);
-    static XMLCh checkRevocation[] =	    UNICODE_LITERAL_15(c,h,e,c,k,R,e,v,o,c,a,t,i,o,n);
+    static XMLCh fullCRLChain[] =           UNICODE_LITERAL_12(f,u,l,l,C,R,L,C,h,a,i,n);
+    static XMLCh checkRevocation[] =        UNICODE_LITERAL_15(c,h,e,c,k,R,e,v,o,c,a,t,i,o,n);
     static XMLCh policyMappingInhibit[] =   UNICODE_LITERAL_20(p,o,l,i,c,y,M,a,p,p,i,n,g,I,n,h,i,b,i,t);
-    static XMLCh anyPolicyInhibit[] =	    UNICODE_LITERAL_16(a,n,y,P,o,l,i,c,y,I,n,h,i,b,i,t);
+    static XMLCh anyPolicyInhibit[] =       UNICODE_LITERAL_16(a,n,y,P,o,l,i,c,y,I,n,h,i,b,i,t);
     static XMLCh _PathValidator[] =         UNICODE_LITERAL_13(P,a,t,h,V,a,l,i,d,a,t,o,r);
-    static XMLCh PolicyOID[] =			    UNICODE_LITERAL_9(P,o,l,i,c,y,O,I,D);
-    static XMLCh TrustedName[] =		    UNICODE_LITERAL_11(T,r,u,s,t,e,d,N,a,m,e);
+    static XMLCh PolicyOID[] =              UNICODE_LITERAL_9(P,o,l,i,c,y,O,I,D);
+    static XMLCh TrustedName[] =            UNICODE_LITERAL_11(T,r,u,s,t,e,d,N,a,m,e);
     static XMLCh type[] =                   UNICODE_LITERAL_4(t,y,p,e);
 };
 
@@ -120,33 +121,30 @@ AbstractPKIXTrustEngine::PKIXValidationInfoIterator::~PKIXValidationInfoIterator
 {
 }
 
-AbstractPKIXTrustEngine::AbstractPKIXTrustEngine(const xercesc::DOMElement* e)
-	: TrustEngine(e),
-		m_checkRevocation(XMLHelper::getAttrString(e, nullptr, checkRevocation)),
-		m_fullCRLChain(XMLHelper::getAttrBool(e, false, fullCRLChain)),
-		m_policyMappingInhibit(XMLHelper::getAttrBool(e, false, policyMappingInhibit)),
-		m_anyPolicyInhibit(XMLHelper::getAttrBool(e, false, anyPolicyInhibit))
+AbstractPKIXTrustEngine::AbstractPKIXTrustEngine(const xercesc::DOMElement* e, bool deprecationSupport)
+    : TrustEngine(e, deprecationSupport),
+        m_checkRevocation(XMLHelper::getAttrString(e, nullptr, checkRevocation)),
+        m_policyMappingInhibit(XMLHelper::getAttrBool(e, false, policyMappingInhibit)),
+        m_anyPolicyInhibit(XMLHelper::getAttrBool(e, false, anyPolicyInhibit))
 {
-    if (m_fullCRLChain) {
+    if (m_checkRevocation.empty() && deprecationSupport && XMLHelper::getAttrBool(e, false, fullCRLChain)) {
         Category::getInstance(XMLTOOLING_LOGCAT ".TrustEngine.PKIX").warn(
-            "fullCRLChain option is deprecated, setting checkRevocation to \"fullChain\""
+            "DEPRECATED: replace fullCRLChain option with checkRevocation set to \"fullChain\""
             );
         m_checkRevocation = "fullChain";
     }
-    else if (m_checkRevocation == "fullChain") {
-        m_fullCRLChain = true; // in case anything's using this
-    }
 
     xercesc::DOMElement* c = XMLHelper::getFirstChildElement(e);
     while (c) {
-        if (c->hasChildNodes()) {
-            auto_ptr_char v(c->getTextContent());
-            if (v.get() && *v.get()) {
-                if (XMLString::equals(c->getLocalName(), PolicyOID))
-                    m_policyOIDs.insert(v.get());
-                else if (XMLString::equals(c->getLocalName(), TrustedName))
-                    m_trustedNames.insert(v.get());
-            }
+        if (XMLString::equals(c->getLocalName(), PolicyOID)) {
+            auto_ptr_char v(XMLHelper::getTextContent(c));
+            if (v.get() && *v.get())
+                m_policyOIDs.insert(v.get());
+        }
+        else if (XMLString::equals(c->getLocalName(), TrustedName)) {
+            auto_ptr_char v(XMLHelper::getTextContent(c));
+            if (v.get() && *v.get())
+                m_trustedNames.insert(v.get());
         }
         else if (XMLString::equals(c->getLocalName(), _PathValidator)) {
             try {
@@ -155,7 +153,7 @@ AbstractPKIXTrustEngine::AbstractPKIXTrustEngine(const xercesc::DOMElement* e)
                     Category::getInstance(XMLTOOLING_LOGCAT ".TrustEngine.PKIX").info(
                         "building PathValidator of type %s", t.c_str()
                         );
-                    PathValidator* pv = XMLToolingConfig::getConfig().PathValidatorManager.newPlugin(t.c_str(), c);
+                    PathValidator* pv = XMLToolingConfig::getConfig().PathValidatorManager.newPlugin(t.c_str(), c, deprecationSupport);
                     OpenSSLPathValidator* ospv = dynamic_cast<OpenSSLPathValidator*>(pv);
                     if (!ospv) {
                         delete pv;
@@ -165,7 +163,7 @@ AbstractPKIXTrustEngine::AbstractPKIXTrustEngine(const xercesc::DOMElement* e)
                     m_pathValidators.push_back(ptr);
                 }
             }
-            catch (exception& ex) {
+            catch (const exception& ex) {
                 Category::getInstance(XMLTOOLING_LOGCAT ".TrustEngine.PKIX").error(
                     "error building PathValidator: %s", ex.what()
                     );
@@ -177,7 +175,7 @@ AbstractPKIXTrustEngine::AbstractPKIXTrustEngine(const xercesc::DOMElement* e)
     if (m_pathValidators.empty()) {
         boost::shared_ptr<OpenSSLPathValidator> ptr(
             dynamic_cast<OpenSSLPathValidator*>(
-                XMLToolingConfig::getConfig().PathValidatorManager.newPlugin(PKIX_PATHVALIDATOR, e)
+                XMLToolingConfig::getConfig().PathValidatorManager.newPlugin(PKIX_PATHVALIDATOR, e, deprecationSupport)
                 )
             );
         m_pathValidators.push_back(ptr);
@@ -375,7 +373,7 @@ bool AbstractPKIXTrustEngine::validateWithCRLs(
     
     log.debug("performing certificate path validation...");
 
-    auto_ptr<PKIXValidationInfoIterator> pkix(getPKIXValidationInfoIterator(credResolver, criteria));
+    scoped_ptr<PKIXValidationInfoIterator> pkix(getPKIXValidationInfoIterator(credResolver, criteria));
     while (pkix->next()) {
         PKIXParams params(*this, *pkix.get(), inlineCRLs);
         for (vector< boost::shared_ptr<OpenSSLPathValidator> >::const_iterator v = m_pathValidators.begin(); v != m_pathValidators.end(); ++v) {
@@ -448,8 +446,8 @@ bool AbstractPKIXTrustEngine::validate(
 
     // Pull the certificate chain out of the signature.
     X509Credential* x509cred;
-    auto_ptr<Credential> cred(inlineResolver->resolve(&sig,X509Credential::RESOLVE_CERTS|X509Credential::RESOLVE_CRLS));
-    if (!cred.get() || !(x509cred=dynamic_cast<X509Credential*>(cred.get()))) {
+    scoped_ptr<Credential> cred(inlineResolver->resolve(&sig,X509Credential::RESOLVE_CERTS|X509Credential::RESOLVE_CRLS));
+    if (!cred || !(x509cred=dynamic_cast<X509Credential*>(cred.get()))) {
         log.error("unable to perform PKIX validation, signature does not contain any certificates");
         return false;
     }
@@ -467,7 +465,7 @@ bool AbstractPKIXTrustEngine::validate(
     SignatureValidator keyValidator;
     for (vector<XSECCryptoX509*>::const_iterator i=certs.begin(); !certEE && i!=certs.end(); ++i) {
         try {
-            auto_ptr<XSECCryptoKey> key((*i)->clonePublicKey());
+            scoped_ptr<XSECCryptoKey> key((*i)->clonePublicKey());
             keyValidator.setKey(key.get());
             keyValidator.validate(&sig);
             log.debug("signature verified with key inside signature, attempting certificate validation...");
@@ -526,8 +524,8 @@ bool AbstractPKIXTrustEngine::validate(
 
     // Pull the certificate chain out of the signature.
     X509Credential* x509cred;
-    auto_ptr<Credential> cred(inlineResolver->resolve(keyInfo,X509Credential::RESOLVE_CERTS));
-    if (!cred.get() || !(x509cred=dynamic_cast<X509Credential*>(cred.get()))) {
+    scoped_ptr<Credential> cred(inlineResolver->resolve(keyInfo,X509Credential::RESOLVE_CERTS));
+    if (!cred || !(x509cred=dynamic_cast<X509Credential*>(cred.get()))) {
         log.error("unable to perform PKIX validation, KeyInfo does not contain any certificates");
         return false;
     }
@@ -544,7 +542,7 @@ bool AbstractPKIXTrustEngine::validate(
     XSECCryptoX509* certEE=nullptr;
     for (vector<XSECCryptoX509*>::const_iterator i=certs.begin(); !certEE && i!=certs.end(); ++i) {
         try {
-            auto_ptr<XSECCryptoKey> key((*i)->clonePublicKey());
+            scoped_ptr<XSECCryptoKey> key((*i)->clonePublicKey());
             if (Signature::verifyRawSignature(key.get(), sigAlgorithm, sig, in, in_len)) {
                 log.debug("signature verified with key inside signature, attempting certificate validation...");
                 certEE=(*i);
